@@ -2,8 +2,8 @@ use crate::gen::fs;
 use crate::syntax;
 use codespan_reporting::diagnostic::{Diagnostic, Label};
 use codespan_reporting::files::SimpleFiles;
-use codespan_reporting::term::termcolor::{ColorChoice, StandardStream, WriteColor};
-use codespan_reporting::term::{self, Config};
+use codespan_reporting::term::termcolor::{ColorChoice, StandardStream};
+use codespan_reporting::term::{self, Config, WriteStyle};
 use std::borrow::Cow;
 use std::error::Error as StdError;
 use std::fmt::{self, Display};
@@ -111,7 +111,7 @@ fn sort_syn_errors(error: syn::Error) -> Vec<syn::Error> {
     errors
 }
 
-fn display_syn_error(stderr: &mut dyn WriteColor, path: &Path, source: &str, error: syn::Error) {
+fn display_syn_error(stderr: &mut dyn WriteStyle, path: &Path, source: &str, error: syn::Error) {
     let span = error.span();
     let start = span.start();
     let end = span.end();
@@ -152,7 +152,7 @@ fn display_syn_error(stderr: &mut dyn WriteColor, path: &Path, source: &str, err
     let diagnostic = diagnose(file, start_offset..end_offset, error);
 
     let config = Config::default();
-    let _ = term::emit(stderr, &config, &files, &diagnostic);
+    let _ = term::emit_to_write_style(stderr, &config, &files, &diagnostic);
 }
 
 fn diagnose(file: usize, range: Range<usize>, error: syn::Error) -> Diagnostic<usize> {
